@@ -2,69 +2,45 @@ from pathlib import Path
 import shutil
 import subprocess
 from textwrap import dedent
-import os
 
-from pythonanywhere.api import Webapp
 from pythonanywhere.exceptions import SanityException
 from pythonanywhere.snakesay import snakesay
-from pythonanywhere.virtualenvs import create_virtualenv, virtualenv_path
-
-
-class DjangoProject:
-
-    def __init__(self, domain):
-        self.domain = domain
-        self.project_path = Path('~/').expanduser() / self.domain
-        self.wsgi_file_path = '/var/www/' + domain.replace('.', '_') + '_wsgi.py'
-        self.webapp = Webapp(domain)
-        self.virtualenv_path = virtualenv_path(domain)
-
-
-    def sanity_checks(self, nuke):
-        self.webapp.sanity_checks(nuke=nuke)
-        if nuke:
-            return
-        if self.virtualenv_path.exists():
-            raise SanityException(f'You already have a virtualenv for {self.domain}.\n\nUse the --nuke option if you want to replace it.')
-        if self.project_path.exists():
-            raise SanityException(f'You already have a project folder at {self.project_path}.\n\nUse the --nuke option if you want to replace it.')
+from .project import Project
 
 
+class DjangoProject(Project):
 
     def download_repo(self, repo, nuke):
-        if nuke:
+        if nuke and self.project_path.exists():
             shutil.rmtree(self.project_path)
         subprocess.check_call(['git', 'clone', repo, self.project_path])
 
 
-    def create_virtualenv(self, python_version, django_version=None, nuke=False):
+    def create_virtualenv(self, django_version=None, nuke=False):
+        self.virtualenv.create(nuke=nuke)
         if django_version is None:
-            packages = self.detect_django_version()
+            packages = self.detect_requirements()
         elif django_version == 'latest':
             packages = 'django'
         else:
             packages = f'django=={django_version}'
-        self.virtualenv_path = create_virtualenv(
-            self.domain, python_version, packages, nuke=nuke
-        )
-        self.python_version = python_version
+        self.virtualenv.pip_install(packages)
 
 
-    def detect_django_version(self):
+    def detect_requirements(self):
         requirements_txt = self.project_path / 'requirements.txt'
         if requirements_txt.exists():
             return f'-r {requirements_txt.resolve()}'
-        return 'django'
-
+        return 'django<2'  # FIXME: this is a hack for djangogirls while they update to 2.x
 
 
     def run_startproject(self, nuke):
         print(snakesay('Starting Django project'))
-        if nuke:
+        if nuke and self.project_path.exists():
             shutil.rmtree(self.project_path)
         self.project_path.mkdir()
         subprocess.check_call([
-            Path(self.virtualenv_path) / 'bin/django-admin.py',
+            Path(self.virtualenv.path) / 'bin/django-admin.py',
             'startproject',
             'mysite',
             self.project_path
@@ -105,25 +81,25 @@ class DjangoProject:
     def run_collectstatic(self):
         print(snakesay('Running collectstatic'))
         subprocess.check_call([
-            Path(self.virtualenv_path) / 'bin/python',
+            Path(self.virtualenv.path) / 'bin/python',
             self.manage_py_path,
             'collectstatic',
             '--noinput',
         ])
 
 
+    def run_migrate(self):
+        print(snakesay('Running migrate database'))
+        subprocess.check_call([
+            Path(self.virtualenv.path) / 'bin/python',
+            self.manage_py_path,
+            'migrate',
+        ])
+
+
     def update_wsgi_file(self):
         print(snakesay(f'Updating wsgi file at {self.wsgi_file_path}'))
         template = open(Path(__file__).parent / 'wsgi_file_template.py').read()
         with open(self.wsgi_file_path, 'w') as f:
             f.write(template.format(project=self))
 
-
-    def create_webapp(self, nuke):
-        self.webapp.create(self.python_version, self.virtualenv_path, self.project_path, nuke=nuke)
-
-
-    def add_static_file_mappings(self):
-        self.webapp.add_default_static_files_mappings(self.project_path)
-
-
